WebGL2RenderingContext extension type

The WebGL2RenderingContext interface provides the OpenGL ES 3.0 rendering context for the drawing surface of an HTML canvas element.

To get an object of this interface, call HTMLCanvasElement.getContext on a <canvas> element, supplying "webgl2" as the argument:

const canvas = document.getElementById("myCanvas");
const gl = canvas.getContext("webgl2");

Note: WebGL 2 is an extension to WebGL 1. The WebGL2RenderingContext interface implements all members of the WebGLRenderingContext interface. Some methods of the WebGL 1 context can accept additional values when used in a WebGL 2 context. You will find this info noted on the WebGL 1 reference pages.

The WebGL tutorial has more information, examples, and resources on how to get started with WebGL.


API documentation sourced from MDN Web Docs.

on
Implemented types
Available extensions

Properties

asString String

Available on JSAny, provided by the JSAnyExtension extension

no setter
asString String?

Available on JSAny?, provided by the JSAnyNullableExtension extension

no setter
canvas JSObject
no setter
drawingBufferColorSpace String
getter/setter pair
drawingBufferHeight int
no setter
drawingBufferWidth int
no setter
entries Iterable<MapEntry<String, dynamic>>

Available on JSObject, provided by the JSObjectExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
isDefinedAndNotNull bool

Available on JSAny?, provided by the NullableUndefineableJSAnyExtension extension

no setter
isElement bool

Available on JSObject?, provided by the JSObjectWebExtension extension

no setter
isHTMLElement bool

Available on JSObject?, provided by the JSObjectWebExtension extension

no setter
isNode bool

Available on JSObject?, provided by the JSObjectWebExtension extension

no setter
isNull bool

Available on JSAny?, provided by the NullableUndefineableJSAnyExtension extension

Whether this value corresponds to JavaScript null.
no setter
isTruthy JSBoolean

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of !!this in JavaScript.
no setter
isUndefined bool

Available on JSAny?, provided by the NullableUndefineableJSAnyExtension extension

Whether this value corresponds to JavaScript undefined.
no setter
isUndefinedOrNull bool

Available on JSAny?, provided by the NullableUndefineableJSAnyExtension extension

no setter
keys Iterable<String>

Available on JSObject, provided by the JSObjectExtension extension

no setter
not JSBoolean

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of !this in JavaScript.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

activeTexture(GLenum texture) → void
add(JSAny? any) JSAny

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of this + any in JavaScript.
and(JSAny? any) JSAny?

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of this && any in JavaScript.
as<T extends JSObject>() → T?

Available on JSObject, provided by the JSObjectExtension extension

attachShader(WebGLProgram program, WebGLShader shader) → void
beginQuery(GLenum target, WebGLQuery query) → void
The WebGL2RenderingContext.beginQuery() method of the WebGL 2 API starts an asynchronous query. The target parameter indicates which kind of query to begin.
beginTransformFeedback(GLenum primitiveMode) → void
The WebGL2RenderingContext.beginTransformFeedback() method of the WebGL 2 API starts a transform feedback operation.
bindAttribLocation(WebGLProgram program, GLuint index, String name) → void
bindBuffer(GLenum target, WebGLBuffer? buffer) → void
bindBufferBase(GLenum target, GLuint index, WebGLBuffer? buffer) → void
The WebGL2RenderingContext.bindBufferBase() method of the WebGL 2 API binds a given WebGLBuffer to a given binding point (target) at a given index.
bindBufferRange(GLenum target, GLuint index, WebGLBuffer? buffer, GLintptr offset, GLsizeiptr size) → void
The WebGL2RenderingContext.bindBufferRange() method of the WebGL 2 API binds a range of a given WebGLBuffer to a given binding point (target) at a given index.
bindFramebuffer(GLenum target, WebGLFramebuffer? framebuffer) → void
bindRenderbuffer(GLenum target, WebGLRenderbuffer? renderbuffer) → void
bindSampler(GLuint unit, WebGLSampler? sampler) → void
The WebGL2RenderingContext.bindSampler() method of the WebGL 2 API binds a passed WebGLSampler object to the texture unit at the passed index.
bindTexture(GLenum target, WebGLTexture? texture) → void
bindTransformFeedback(GLenum target, WebGLTransformFeedback? tf) → void
The WebGL2RenderingContext.bindTransformFeedback() method of the WebGL 2 API binds a passed WebGLTransformFeedback object to the current GL state.
bindVertexArray(WebGLVertexArrayObject? array) → void
The WebGL2RenderingContext.bindVertexArray() method of the WebGL 2 API binds a passed WebGLVertexArrayObject object to the buffer.
blendColor(GLclampf red, GLclampf green, GLclampf blue, GLclampf alpha) → void
blendEquation(GLenum mode) → void
blendEquationSeparate(GLenum modeRGB, GLenum modeAlpha) → void
blendFunc(GLenum sfactor, GLenum dfactor) → void
blendFuncSeparate(GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha) → void
blitFramebuffer(GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter) → void
The WebGL2RenderingContext.blitFramebuffer() method of the WebGL 2 API transfers a block of pixels from the read framebuffer to the draw framebuffer. Read and draw framebuffers are bound using WebGLRenderingContext.bindFramebuffer.
bufferData(GLenum target, JSAny? sizeOrSrcData, GLenum usage, [int srcOffset, GLuint length]) → void
The WebGL2RenderingContext.bufferData() method of the WebGL API creates and initializes the buffer object's data store.
bufferSubData(GLenum target, GLintptr dstByteOffset, JSObject srcData, [int srcOffset, GLuint length]) → void
The WebGL2RenderingContext.bufferSubData() method of the WebGL API updates a subset of a buffer object's data store.
callMethod<R extends JSAny?>(JSAny method, [JSAny? arg1, JSAny? arg2, JSAny? arg3, JSAny? arg4]) → R

Available on JSObject, provided by the JSObjectUnsafeUtilExtension extension

Calls method on this JSObject with up to four arguments.
callMethodVarArgs<R extends JSAny?>(JSAny method, [List<JSAny?>? arguments]) → R

Available on JSObject, provided by the JSObjectUnsafeUtilExtension extension

Calls method on this JSObject with a variable number of arguments.
checkFramebufferStatus(GLenum target) GLenum
clear(GLbitfield mask) → void
clearBufferfi(GLenum buffer, GLint drawbuffer, GLfloat depth, GLint stencil) → void
clearBufferfv(GLenum buffer, GLint drawbuffer, Float32List values, [int srcOffset]) → void
clearBufferiv(GLenum buffer, GLint drawbuffer, Int32List values, [int srcOffset]) → void
clearBufferuiv(GLenum buffer, GLint drawbuffer, Uint32List values, [int srcOffset]) → void
clearColor(GLclampf red, GLclampf green, GLclampf blue, GLclampf alpha) → void
clearDepth(GLclampf depth) → void
clearStencil(GLint s) → void
clientWaitSync(WebGLSync sync, GLbitfield flags, GLuint64 timeout) GLenum
The WebGL2RenderingContext.clientWaitSync() method of the WebGL 2 API blocks and waits for a WebGLSync object to become signaled or a given timeout to be passed.
colorMask(GLboolean red, GLboolean green, GLboolean blue, GLboolean alpha) → void
compileShader(WebGLShader shader) → void
compressedTexImage2D(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLint border, JSAny imageSizeOrSrcData, [JSAny offsetOrSrcOffset, GLuint srcLengthOverride]) → void
compressedTexImage3D(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, JSAny imageSizeOrSrcData, [JSAny offsetOrSrcOffset, GLuint srcLengthOverride]) → void
compressedTexSubImage2D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, JSAny imageSizeOrSrcData, [JSAny offsetOrSrcOffset, GLuint srcLengthOverride]) → void
compressedTexSubImage3D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, JSAny imageSizeOrSrcData, [JSAny offsetOrSrcOffset, GLuint srcLengthOverride]) → void
The WebGL2RenderingContext.compressedTexSubImage3D() method of the WebGL API specifies a three-dimensional sub-rectangle for a texture image in a compressed format.
copyBufferSubData(GLenum readTarget, GLenum writeTarget, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size) → void
The WebGL2RenderingContext.copyBufferSubData() method of the WebGL 2 API copies part of the data of a buffer to another buffer.
copyTexImage2D(GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height, GLint border) → void
copyTexSubImage2D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height) → void
copyTexSubImage3D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height) → void
The WebGL2RenderingContext.copyTexSubImage3D() method of the WebGL API copies pixels from the current WebGLFramebuffer into an existing 3D texture sub-image.
createBuffer() WebGLBuffer?
createFramebuffer() WebGLFramebuffer?
createProgram() WebGLProgram?
createQuery() WebGLQuery?
The WebGL2RenderingContext.createQuery() method of the WebGL 2 API creates and initializes WebGLQuery objects, which provide ways to asynchronously query for information.
createRenderbuffer() WebGLRenderbuffer?
createSampler() WebGLSampler?
The WebGL2RenderingContext.createSampler() method of the WebGL 2 API creates and initializes WebGLSampler objects.
createShader(GLenum type) WebGLShader?
createTexture() WebGLTexture?
createTransformFeedback() WebGLTransformFeedback?
The WebGL2RenderingContext.createTransformFeedback() method of the WebGL 2 API creates and initializes WebGLTransformFeedback objects.
createVertexArray() WebGLVertexArrayObject?
The WebGL2RenderingContext.createVertexArray() method of the WebGL 2 API creates and initializes a WebGLVertexArrayObject object that represents a vertex array object (VAO) pointing to vertex array data and which provides names for different sets of vertex data.
cullFace(GLenum mode) → void
dartify() Object?

Available on JSAny?, provided by the JSAnyUtilityExtension extension

Converts a JavaScript JSON-like value to the Dart equivalent if possible.
delete(JSAny property) JSBoolean

Available on JSObject, provided by the JSObjectUnsafeUtilExtension extension

Deletes the property with key property from this JSObject.
deleteBuffer(WebGLBuffer? buffer) → void
deleteFramebuffer(WebGLFramebuffer? framebuffer) → void
deleteProgram(WebGLProgram? program) → void
deleteQuery(WebGLQuery? query) → void
The WebGL2RenderingContext.deleteQuery() method of the WebGL 2 API deletes a given WebGLQuery object.
deleteRenderbuffer(WebGLRenderbuffer? renderbuffer) → void
deleteSampler(WebGLSampler? sampler) → void
The WebGL2RenderingContext.deleteSampler() method of the WebGL 2 API deletes a given WebGLSampler object.
deleteShader(WebGLShader? shader) → void
deleteSync(WebGLSync? sync) → void
The WebGL2RenderingContext.deleteSync() method of the WebGL 2 API deletes a given WebGLSync object.
deleteTexture(WebGLTexture? texture) → void
deleteTransformFeedback(WebGLTransformFeedback? tf) → void
The WebGL2RenderingContext.deleteTransformFeedback() method of the WebGL 2 API deletes a given WebGLTransformFeedback object.
deleteVertexArray(WebGLVertexArrayObject? vertexArray) → void
The WebGL2RenderingContext.deleteVertexArray() method of the WebGL 2 API deletes a given WebGLVertexArrayObject object.
depthFunc(GLenum func) → void
depthMask(GLboolean flag) → void
depthRange(GLclampf zNear, GLclampf zFar) → void
detachShader(WebGLProgram program, WebGLShader shader) → void
disable(GLenum cap) → void
disableVertexAttribArray(GLuint index) → void
divide(JSAny? any) JSAny

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of this / any in JavaScript.
drawArrays(GLenum mode, GLint first, GLsizei count) → void
drawArraysInstanced(GLenum mode, GLint first, GLsizei count, GLsizei instanceCount) → void
The WebGL2RenderingContext.drawArraysInstanced() method of the WebGL 2 API renders primitives from array data like the WebGLRenderingContext.drawArrays method. In addition, it can execute multiple instances of the range of elements.
drawBuffers(JSArray<JSNumber> buffers) → void
The WebGL2RenderingContext.drawBuffers() method of the WebGL 2 API defines draw buffers to which fragment colors are written into. The draw buffer settings are part of the state of the currently bound framebuffer or the drawingbuffer if no framebuffer is bound.
drawElements(GLenum mode, GLsizei count, GLenum type, GLintptr offset) → void
drawElementsInstanced(GLenum mode, GLsizei count, GLenum type, GLintptr offset, GLsizei instanceCount) → void
The WebGL2RenderingContext.drawElementsInstanced() method of the WebGL 2 API renders primitives from array data like the WebGLRenderingContext.drawElements method. In addition, it can execute multiple instances of a set of elements.
drawRangeElements(GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, GLintptr offset) → void
The WebGL2RenderingContext.drawRangeElements() method of the WebGL API renders primitives from array data in a given range.
enable(GLenum cap) → void
enableVertexAttribArray(GLuint index) → void
endQuery(GLenum target) → void
The WebGL2RenderingContext.endQuery() method of the WebGL 2 API marks the end of a given query target.
endTransformFeedback() → void
The WebGL2RenderingContext.endTransformFeedback() method of the WebGL 2 API ends a transform feedback operation.
equals(JSAny? any) JSBoolean

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of this == any in JavaScript.
exponentiate(JSAny? any) JSAny

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of this ** any in JavaScript.
fenceSync(GLenum condition, GLbitfield flags) WebGLSync?
The WebGL2RenderingContext.fenceSync() method of the WebGL 2 API creates a new WebGLSync object and inserts it into the GL command stream.
finish() → void
flush() → void
framebufferRenderbuffer(GLenum target, GLenum attachment, GLenum renderbuffertarget, WebGLRenderbuffer? renderbuffer) → void
framebufferTexture2D(GLenum target, GLenum attachment, GLenum textarget, WebGLTexture? texture, GLint level) → void
framebufferTextureLayer(GLenum target, GLenum attachment, WebGLTexture? texture, GLint level, GLint layer) → void
The WebGL2RenderingContext.framebufferTextureLayer() method of the WebGL 2 API attaches a single layer of a texture to a framebuffer.
frontFace(GLenum mode) → void
generateMipmap(GLenum target) → void
get(String key) Object?

Available on JSObject, provided by the JSObjectExtension extension

getActiveAttrib(WebGLProgram program, GLuint index) WebGLActiveInfo?
getActiveUniform(WebGLProgram program, GLuint index) WebGLActiveInfo?
getActiveUniformBlockName(WebGLProgram program, GLuint uniformBlockIndex) String?
The WebGL2RenderingContext.getActiveUniformBlockName() method of the WebGL 2 API retrieves the name of the active uniform block at a given index within a WebGLProgram.
getActiveUniformBlockParameter(WebGLProgram program, GLuint uniformBlockIndex, GLenum pname) JSAny?
The WebGL2RenderingContext.getActiveUniformBlockParameter() method of the WebGL 2 API retrieves information about an active uniform block within a WebGLProgram.
getActiveUniforms(WebGLProgram program, JSArray<JSNumber> uniformIndices, GLenum pname) JSAny?
The WebGL2RenderingContext.getActiveUniforms() method of the WebGL 2 API retrieves information about active uniforms within a WebGLProgram.
getAttachedShaders(WebGLProgram program) JSArray<WebGLShader>?
getAttribLocation(WebGLProgram program, String name) GLint
getBufferParameter(GLenum target, GLenum pname) JSAny?
getBufferSubData(GLenum target, GLintptr srcByteOffset, ArrayBufferView dstBuffer, [int dstOffset, GLuint length]) → void
The WebGL2RenderingContext.getBufferSubData() method of the WebGL 2 API reads data from a buffer binding point and writes them to an ArrayBuffer or SharedArrayBuffer.
getContextAttributes() WebGLContextAttributes?
getError() int
getExtension(String name) JSObject?
getFragDataLocation(WebGLProgram program, String name) GLint
The WebGL2RenderingContext.getFragDataLocation() method of the WebGL 2 API returns the binding of color numbers to user-defined varying out variables.
getFramebufferAttachmentParameter(GLenum target, GLenum attachment, GLenum pname) JSAny?
getIndexedParameter(GLenum target, GLuint index) JSAny?
The WebGL2RenderingContext.getIndexedParameter() method of the WebGL 2 API returns indexed information about a given target.
getInternalformatParameter(GLenum target, GLenum internalformat, GLenum pname) JSAny?
The WebGL2RenderingContext.getInternalformatParameter() method of the WebGL 2 API returns information about implementation-dependent support for internal formats.
getParameter(GLenum pname) JSAny?
getProgramInfoLog(WebGLProgram program) String?
getProgramParameter(WebGLProgram program, GLenum pname) JSAny?
getProperty<R extends JSAny?>(JSAny property) → R

Available on JSObject, provided by the JSObjectUnsafeUtilExtension extension

The value of the property key property of this JSObject.
getQuery(GLenum target, GLenum pname) WebGLQuery?
The WebGL2RenderingContext.getQuery() method of the WebGL 2 API returns the currently active WebGLQuery for the target, or null.
getQueryParameter(WebGLQuery query, GLenum pname) JSAny?
The WebGL2RenderingContext.getQueryParameter() method of the WebGL 2 API returns parameter information of a WebGLQuery object.
getRenderbufferParameter(GLenum target, GLenum pname) JSAny?
getSamplerParameter(WebGLSampler sampler, GLenum pname) JSAny?
The WebGL2RenderingContext.getSamplerParameter() method of the WebGL 2 API returns parameter information of a WebGLSampler object.
getShaderInfoLog(WebGLShader shader) String?
getShaderParameter(WebGLShader shader, GLenum pname) JSAny?
getShaderPrecisionFormat(GLenum shadertype, GLenum precisiontype) WebGLShaderPrecisionFormat?
getShaderSource(WebGLShader shader) String?
getSupportedExtensions() JSArray<JSString>?
getSyncParameter(WebGLSync sync, GLenum pname) JSAny?
The WebGL2RenderingContext.getSyncParameter() method of the WebGL 2 API returns parameter information of a WebGLSync object.
getTexParameter(GLenum target, GLenum pname) JSAny?
getTransformFeedbackVarying(WebGLProgram program, GLuint index) WebGLActiveInfo?
The WebGL2RenderingContext.getTransformFeedbackVarying() method of the WebGL 2 API returns information about varying variables from WebGLTransformFeedback buffers.
getUniform(WebGLProgram program, WebGLUniformLocation location) JSAny?
getUniformBlockIndex(WebGLProgram program, String uniformBlockName) GLint
The WebGL2RenderingContext.getUniformBlockIndex() method of the WebGL 2 API retrieves the index of a uniform block within a WebGLProgram.
getUniformIndices(WebGLProgram program, JSArray<JSString> uniformNames) JSArray<JSNumber>?
The WebGL2RenderingContext.getUniformIndices() method of the WebGL 2 API retrieves the indices of a number of uniforms within a WebGLProgram.
getUniformLocation(WebGLProgram program, String name) WebGLUniformLocation?
getVertexAttrib(GLuint index, GLenum pname) JSAny?
getVertexAttribOffset(GLuint index, GLenum pname) GLintptr
greaterThan(JSAny? any) JSBoolean

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of this > any in JavaScript.
greaterThanOrEqualTo(JSAny? any) JSBoolean

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of this >= any in JavaScript.
has(String property) bool

Available on JSObject, provided by the JSObjectUnsafeUtilExtension extension

Shorthand helper for hasProperty to check whether this JSObject contains the property key property, but takes and returns a Dart value.
hasProperty(JSAny property) JSBoolean

Available on JSObject, provided by the JSObjectUnsafeUtilExtension extension

Whether or not this JSObject contains the property key property.
hint(GLenum target, GLenum mode) → void
instanceof(JSFunction constructor) bool

Available on JSAny?, provided by the JSAnyUtilityExtension extension

Whether this JSAny? is an instanceof constructor.
instanceOfString(String constructorName) bool

Available on JSAny?, provided by the JSAnyUtilityExtension extension

Whether this JSAny? is an instanceof the constructor that is defined by constructorName, which is looked up in the globalContext.
invalidateFramebuffer(GLenum target, JSArray<JSNumber> attachments) → void
The WebGL2RenderingContext.invalidateFramebuffer() method of the WebGL 2 API invalidates the contents of attachments in a framebuffer.
invalidateSubFramebuffer(GLenum target, JSArray<JSNumber> attachments, GLint x, GLint y, GLsizei width, GLsizei height) → void
The WebGL2RenderingContext.invalidateSubFramebuffer() method of the WebGL 2 API invalidates portions of the contents of attachments in a framebuffer.
isBuffer(WebGLBuffer? buffer) GLboolean
isContextLost() bool
isEnabled(GLenum cap) GLboolean
isFramebuffer(WebGLFramebuffer? framebuffer) GLboolean
isProgram(WebGLProgram? program) GLboolean
isQuery(WebGLQuery? query) GLboolean
The WebGL2RenderingContext.isQuery() method of the WebGL 2 API returns true if the passed object is a valid WebGLQuery object.
isRenderbuffer(WebGLRenderbuffer? renderbuffer) GLboolean
isSampler(WebGLSampler? sampler) GLboolean
The WebGL2RenderingContext.isSampler() method of the WebGL 2 API returns true if the passed object is a valid WebGLSampler object.
isShader(WebGLShader? shader) GLboolean
isSync(WebGLSync? sync) GLboolean
The WebGL2RenderingContext.isSync() method of the WebGL 2 API returns true if the passed object is a valid WebGLSync object.
isTexture(WebGLTexture? texture) GLboolean
isTransformFeedback(WebGLTransformFeedback? tf) GLboolean
The WebGL2RenderingContext.isTransformFeedback() method of the WebGL 2 API returns true if the passed object is a valid WebGLTransformFeedback object.
isVertexArray(WebGLVertexArrayObject? vertexArray) GLboolean
The WebGL2RenderingContext.isVertexArray() method of the WebGL API returns true if the passed object is a valid WebGLVertexArrayObject object.
lessThan(JSAny? any) JSBoolean

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of this < any in JavaScript.
lessThanOrEqualTo(JSAny? any) JSBoolean

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of this <= any in JavaScript.
lineWidth(GLfloat width) → void
linkProgram(WebGLProgram program) → void
makeXRCompatible() JSPromise<JSAny?>
modulo(JSAny? any) JSAny

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of this % any in JavaScript.
multiply(JSAny? any) JSAny

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of this * any in JavaScript.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notEquals(JSAny? any) JSBoolean

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of this != any in JavaScript.
or(JSAny? any) JSAny?

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of this || any in JavaScript.
pauseTransformFeedback() → void
The WebGL2RenderingContext.pauseTransformFeedback() method of the WebGL 2 API pauses a transform feedback operation.
pixelStorei(GLenum pname, GLint param) → void
polygonOffset(GLfloat factor, GLfloat units) → void
put(Object key, Object? value) → void

Available on JSObject, provided by the JSObjectExtension extension

readBuffer(GLenum src) → void
The WebGL2RenderingContext.readBuffer() method of the WebGL 2 API selects a color buffer as the source for pixels for subsequent calls to WebGLRenderingContext.copyTexImage2D, WebGLRenderingContext.copyTexSubImage2D, WebGL2RenderingContext.copyTexSubImage3D or WebGLRenderingContext.readPixels.
readPixels(GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, JSAny? dstDataOrOffset, [int dstOffset]) → void
renderbufferStorage(GLenum target, GLenum internalformat, GLsizei width, GLsizei height) → void
renderbufferStorageMultisample(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height) → void
The WebGL2RenderingContext.renderbufferStorageMultisample() method of the WebGL 2 API returns creates and initializes a renderbuffer object's data store and allows specifying a number of samples to be used.
resumeTransformFeedback() → void
The WebGL2RenderingContext.resumeTransformFeedback() method of the WebGL 2 API resumes a transform feedback operation.
sampleCoverage(GLclampf value, GLboolean invert) → void
samplerParameterf(WebGLSampler sampler, GLenum pname, GLfloat param) → void
samplerParameteri(WebGLSampler sampler, GLenum pname, GLint param) → void
scissor(GLint x, GLint y, GLsizei width, GLsizei height) → void
setProperty(JSAny property, JSAny? value) → void

Available on JSObject, provided by the JSObjectUnsafeUtilExtension extension

Write the value of property key property of this JSObject.
shaderSource(WebGLShader shader, String source) → void
stencilFunc(GLenum func, GLint ref, GLuint mask) → void
stencilFuncSeparate(GLenum face, GLenum func, GLint ref, GLuint mask) → void
stencilMask(GLuint mask) → void
stencilMaskSeparate(GLenum face, GLuint mask) → void
stencilOp(GLenum fail, GLenum zfail, GLenum zpass) → void
stencilOpSeparate(GLenum face, GLenum fail, GLenum zfail, GLenum zpass) → void
strictEquals(JSAny? any) JSBoolean

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of this === any in JavaScript.
strictNotEquals(JSAny? any) JSBoolean

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of this !== any in JavaScript.
subtract(JSAny? any) JSAny

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of this - any in JavaScript.
texImage2D(GLenum target, GLint level, GLint internalformat, JSAny formatOrWidth, JSAny heightOrType, JSAny borderOrSource, [GLenum format, GLenum type, JSAny? pboOffsetOrPixelsOrSourceOrSrcData, int srcOffset]) → void
texImage3D(GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, JSAny? pboOffsetOrSourceOrSrcData, [int srcOffset]) → void
The WebGLRenderingContext.texImage3D() method of the WebGL API specifies a three-dimensional texture image.
texParameterf(GLenum target, GLenum pname, GLfloat param) → void
texParameteri(GLenum target, GLenum pname, GLint param) → void
texStorage2D(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height) → void
The WebGL2RenderingContext.texStorage2D() method of the WebGL API specifies all levels of two-dimensional texture storage.
texStorage3D(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth) → void
The WebGL2RenderingContext.texStorage3D() method of the WebGL API specifies all levels of a three-dimensional texture or two-dimensional array texture.
texSubImage2D(GLenum target, GLint level, GLint xoffset, GLint yoffset, JSAny formatOrWidth, JSAny heightOrType, JSAny formatOrSource, [GLenum type, JSAny? pboOffsetOrPixelsOrSourceOrSrcData, int srcOffset]) → void
texSubImage3D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, JSAny? pboOffsetOrSourceOrSrcData, [int srcOffset]) → void
The WebGL2RenderingContext.texSubImage3D() method of the WebGL API specifies a sub-rectangle of the current texture.
toMap() Map<String, dynamic>

Available on JSObject, provided by the JSObjectExtension extension

toString() String
A string representation of this object.
inherited
transformFeedbackVaryings(WebGLProgram program, JSArray<JSString> varyings, GLenum bufferMode) → void
The WebGL2RenderingContext.transformFeedbackVaryings() method of the WebGL 2 API specifies values to record in WebGLTransformFeedback buffers.
typeofEquals(String typeString) bool

Available on JSAny?, provided by the JSAnyUtilityExtension extension

Whether the result of typeof on this JSAny? is typeString.
uniform1f(WebGLUniformLocation? location, GLfloat x) → void
uniform1fv(WebGLUniformLocation? location, Float32List data, [int srcOffset, GLuint srcLength]) → void
uniform1i(WebGLUniformLocation? location, GLint x) → void
uniform1iv(WebGLUniformLocation? location, Int32List data, [int srcOffset, GLuint srcLength]) → void
uniform1ui(WebGLUniformLocation? location, GLuint v0) → void
uniform1uiv(WebGLUniformLocation? location, Uint32List data, [int srcOffset, GLuint srcLength]) → void
uniform2f(WebGLUniformLocation? location, GLfloat x, GLfloat y) → void
uniform2fv(WebGLUniformLocation? location, Float32List data, [int srcOffset, GLuint srcLength]) → void
uniform2i(WebGLUniformLocation? location, GLint x, GLint y) → void
uniform2iv(WebGLUniformLocation? location, Int32List data, [int srcOffset, GLuint srcLength]) → void
uniform2ui(WebGLUniformLocation? location, GLuint v0, GLuint v1) → void
uniform2uiv(WebGLUniformLocation? location, Uint32List data, [int srcOffset, GLuint srcLength]) → void
uniform3f(WebGLUniformLocation? location, GLfloat x, GLfloat y, GLfloat z) → void
uniform3fv(WebGLUniformLocation? location, Float32List data, [int srcOffset, GLuint srcLength]) → void
uniform3i(WebGLUniformLocation? location, GLint x, GLint y, GLint z) → void
uniform3iv(WebGLUniformLocation? location, Int32List data, [int srcOffset, GLuint srcLength]) → void
uniform3ui(WebGLUniformLocation? location, GLuint v0, GLuint v1, GLuint v2) → void
uniform3uiv(WebGLUniformLocation? location, Uint32List data, [int srcOffset, GLuint srcLength]) → void
uniform4f(WebGLUniformLocation? location, GLfloat x, GLfloat y, GLfloat z, GLfloat w) → void
uniform4fv(WebGLUniformLocation? location, Float32List data, [int srcOffset, GLuint srcLength]) → void
uniform4i(WebGLUniformLocation? location, GLint x, GLint y, GLint z, GLint w) → void
uniform4iv(WebGLUniformLocation? location, Int32List data, [int srcOffset, GLuint srcLength]) → void
uniform4ui(WebGLUniformLocation? location, GLuint v0, GLuint v1, GLuint v2, GLuint v3) → void
uniform4uiv(WebGLUniformLocation? location, Uint32List data, [int srcOffset, GLuint srcLength]) → void
uniformBlockBinding(WebGLProgram program, GLuint uniformBlockIndex, GLuint uniformBlockBinding) → void
The WebGL2RenderingContext.uniformBlockBinding() method of the WebGL 2 API assigns binding points for active uniform blocks.
uniformMatrix2fv(WebGLUniformLocation? location, GLboolean transpose, Float32List data, [int srcOffset, GLuint srcLength]) → void
uniformMatrix2x3fv(WebGLUniformLocation? location, GLboolean transpose, Float32List data, [int srcOffset, GLuint srcLength]) → void
uniformMatrix2x4fv(WebGLUniformLocation? location, GLboolean transpose, Float32List data, [int srcOffset, GLuint srcLength]) → void
uniformMatrix3fv(WebGLUniformLocation? location, GLboolean transpose, Float32List data, [int srcOffset, GLuint srcLength]) → void
uniformMatrix3x2fv(WebGLUniformLocation? location, GLboolean transpose, Float32List data, [int srcOffset, GLuint srcLength]) → void
uniformMatrix3x4fv(WebGLUniformLocation? location, GLboolean transpose, Float32List data, [int srcOffset, GLuint srcLength]) → void
uniformMatrix4fv(WebGLUniformLocation? location, GLboolean transpose, Float32List data, [int srcOffset, GLuint srcLength]) → void
uniformMatrix4x2fv(WebGLUniformLocation? location, GLboolean transpose, Float32List data, [int srcOffset, GLuint srcLength]) → void
uniformMatrix4x3fv(WebGLUniformLocation? location, GLboolean transpose, Float32List data, [int srcOffset, GLuint srcLength]) → void
unsignedRightShift(JSAny? any) JSNumber

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of this >>> any in JavaScript.
useProgram(WebGLProgram? program) → void
validateProgram(WebGLProgram program) → void
vertexAttrib1f(GLuint index, GLfloat x) → void
vertexAttrib1fv(GLuint index, Float32List values) → void
vertexAttrib2f(GLuint index, GLfloat x, GLfloat y) → void
vertexAttrib2fv(GLuint index, Float32List values) → void
vertexAttrib3f(GLuint index, GLfloat x, GLfloat y, GLfloat z) → void
vertexAttrib3fv(GLuint index, Float32List values) → void
vertexAttrib4f(GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w) → void
vertexAttrib4fv(GLuint index, Float32List values) → void
vertexAttribDivisor(GLuint index, GLuint divisor) → void
The WebGL2RenderingContext.vertexAttribDivisor() method of the WebGL 2 API modifies the rate at which generic vertex attributes advance when rendering multiple instances of primitives with WebGL2RenderingContext.drawArraysInstanced and WebGL2RenderingContext.drawElementsInstanced.
vertexAttribI4i(GLuint index, GLint x, GLint y, GLint z, GLint w) → void
vertexAttribI4iv(GLuint index, Int32List values) → void
vertexAttribI4ui(GLuint index, GLuint x, GLuint y, GLuint z, GLuint w) → void
vertexAttribI4uiv(GLuint index, Uint32List values) → void
vertexAttribIPointer(GLuint index, GLint size, GLenum type, GLsizei stride, GLintptr offset) → void
The WebGL2RenderingContext.vertexAttribIPointer() method of the WebGL 2 API specifies integer data formats and locations of vertex attributes in a vertex attributes array.
vertexAttribPointer(GLuint index, GLint size, GLenum type, GLboolean normalized, GLsizei stride, GLintptr offset) → void
viewport(GLint x, GLint y, GLsizei width, GLsizei height) → void
waitSync(WebGLSync sync, GLbitfield flags, GLint64 timeout) → void
The WebGL2RenderingContext.waitSync() method of the WebGL 2 API returns immediately, but waits on the GL server until the given WebGLSync object is signaled.

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](String property) JSAny?

Available on JSObject, provided by the JSObjectUnsafeUtilExtension extension

Shorthand helper for getProperty to get the value of the property key property of this JSObject, but takes a Dart value.
operator []=(String property, JSAny? value) → void

Available on JSObject, provided by the JSObjectUnsafeUtilExtension extension

Shorthand helper for setProperty to write the value of the property key property of this JSObject, but takes a Dart value.

Constants

ACTIVE_ATTRIBUTES → const int
ACTIVE_TEXTURE → const int
ACTIVE_UNIFORM_BLOCKS → const int
ACTIVE_UNIFORMS → const int
ALIASED_LINE_WIDTH_RANGE → const int
ALIASED_POINT_SIZE_RANGE → const int
ALPHA → const int
ALPHA_BITS → const int
ALREADY_SIGNALED → const int
ALWAYS → const int
ANY_SAMPLES_PASSED → const int
ANY_SAMPLES_PASSED_CONSERVATIVE → const int
ARRAY_BUFFER → const int
ARRAY_BUFFER_BINDING → const int
ATTACHED_SHADERS → const int
BACK → const int
BLEND → const int
BLEND_COLOR → const int
BLEND_DST_ALPHA → const int
BLEND_DST_RGB → const int
BLEND_EQUATION → const int
BLEND_EQUATION_ALPHA → const int
BLEND_EQUATION_RGB → const int
BLEND_SRC_ALPHA → const int
BLEND_SRC_RGB → const int
BLUE_BITS → const int
BOOL → const int
BOOL_VEC2 → const int
BOOL_VEC3 → const int
BOOL_VEC4 → const int
BROWSER_DEFAULT_WEBGL → const int
BUFFER_SIZE → const int
BUFFER_USAGE → const int
BYTE → const int
CCW → const int
CLAMP_TO_EDGE → const int
COLOR → const int
COLOR_ATTACHMENT0 → const int
COLOR_ATTACHMENT1 → const int
COLOR_ATTACHMENT2 → const int
COLOR_ATTACHMENT3 → const int
COLOR_ATTACHMENT4 → const int
COLOR_ATTACHMENT5 → const int
COLOR_ATTACHMENT6 → const int
COLOR_ATTACHMENT7 → const int
COLOR_ATTACHMENT8 → const int
COLOR_ATTACHMENT9 → const int
COLOR_ATTACHMENT10 → const int
COLOR_ATTACHMENT11 → const int
COLOR_ATTACHMENT12 → const int
COLOR_ATTACHMENT13 → const int
COLOR_ATTACHMENT14 → const int
COLOR_ATTACHMENT15 → const int
COLOR_BUFFER_BIT → const int
COLOR_CLEAR_VALUE → const int
COLOR_WRITEMASK → const int
COMPARE_REF_TO_TEXTURE → const int
COMPILE_STATUS → const int
COMPRESSED_TEXTURE_FORMATS → const int
CONDITION_SATISFIED → const int
CONSTANT_ALPHA → const int
CONSTANT_COLOR → const int
CONTEXT_LOST_WEBGL → const int
COPY_READ_BUFFER → const int
COPY_READ_BUFFER_BINDING → const int
COPY_WRITE_BUFFER → const int
COPY_WRITE_BUFFER_BINDING → const int
CULL_FACE → const int
CULL_FACE_MODE → const int
CURRENT_PROGRAM → const int
CURRENT_QUERY → const int
CURRENT_VERTEX_ATTRIB → const int
CW → const int
DECR → const int
DECR_WRAP → const int
DELETE_STATUS → const int
DEPTH → const int
DEPTH24_STENCIL8 → const int
DEPTH32F_STENCIL8 → const int
DEPTH_ATTACHMENT → const int
DEPTH_BITS → const int
DEPTH_BUFFER_BIT → const int
DEPTH_CLEAR_VALUE → const int
DEPTH_COMPONENT → const int
DEPTH_COMPONENT16 → const int
DEPTH_COMPONENT24 → const int
DEPTH_COMPONENT32F → const int
DEPTH_FUNC → const int
DEPTH_RANGE → const int
DEPTH_STENCIL → const int
DEPTH_STENCIL_ATTACHMENT → const int
DEPTH_TEST → const int
DEPTH_WRITEMASK → const int
DITHER → const int
DONT_CARE → const int
DRAW_BUFFER0 → const int
DRAW_BUFFER1 → const int
DRAW_BUFFER2 → const int
DRAW_BUFFER3 → const int
DRAW_BUFFER4 → const int
DRAW_BUFFER5 → const int
DRAW_BUFFER6 → const int
DRAW_BUFFER7 → const int
DRAW_BUFFER8 → const int
DRAW_BUFFER9 → const int
DRAW_BUFFER10 → const int
DRAW_BUFFER11 → const int
DRAW_BUFFER12 → const int
DRAW_BUFFER13 → const int
DRAW_BUFFER14 → const int
DRAW_BUFFER15 → const int
DRAW_FRAMEBUFFER → const int
DRAW_FRAMEBUFFER_BINDING → const int
DST_ALPHA → const int
DST_COLOR → const int
DYNAMIC_COPY → const int
DYNAMIC_DRAW → const int
DYNAMIC_READ → const int
ELEMENT_ARRAY_BUFFER → const int
ELEMENT_ARRAY_BUFFER_BINDING → const int
EQUAL → const int
FASTEST → const int
FLOAT → const int
FLOAT_32_UNSIGNED_INT_24_8_REV → const int
FLOAT_MAT2 → const int
FLOAT_MAT2x3 → const int
FLOAT_MAT2x4 → const int
FLOAT_MAT3 → const int
FLOAT_MAT3x2 → const int
FLOAT_MAT3x4 → const int
FLOAT_MAT4 → const int
FLOAT_MAT4x2 → const int
FLOAT_MAT4x3 → const int
FLOAT_VEC2 → const int
FLOAT_VEC3 → const int
FLOAT_VEC4 → const int
FRAGMENT_SHADER → const int
FRAGMENT_SHADER_DERIVATIVE_HINT → const int
FRAMEBUFFER → const int
FRAMEBUFFER_ATTACHMENT_ALPHA_SIZE → const int
FRAMEBUFFER_ATTACHMENT_BLUE_SIZE → const int
FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING → const int
FRAMEBUFFER_ATTACHMENT_COMPONENT_TYPE → const int
FRAMEBUFFER_ATTACHMENT_DEPTH_SIZE → const int
FRAMEBUFFER_ATTACHMENT_GREEN_SIZE → const int
FRAMEBUFFER_ATTACHMENT_OBJECT_NAME → const int
FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE → const int
FRAMEBUFFER_ATTACHMENT_RED_SIZE → const int
FRAMEBUFFER_ATTACHMENT_STENCIL_SIZE → const int
FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE → const int
FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER → const int
FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL → const int
FRAMEBUFFER_BINDING → const int
FRAMEBUFFER_COMPLETE → const int
FRAMEBUFFER_DEFAULT → const int
FRAMEBUFFER_INCOMPLETE_ATTACHMENT → const int
FRAMEBUFFER_INCOMPLETE_DIMENSIONS → const int
FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT → const int
FRAMEBUFFER_INCOMPLETE_MULTISAMPLE → const int
FRAMEBUFFER_UNSUPPORTED → const int
FRONT → const int
FRONT_AND_BACK → const int
FRONT_FACE → const int
FUNC_ADD → const int
FUNC_REVERSE_SUBTRACT → const int
FUNC_SUBTRACT → const int
GENERATE_MIPMAP_HINT → const int
GEQUAL → const int
GREATER → const int
GREEN_BITS → const int
HALF_FLOAT → const int
HIGH_FLOAT → const int
HIGH_INT → const int
IMPLEMENTATION_COLOR_READ_FORMAT → const int
IMPLEMENTATION_COLOR_READ_TYPE → const int
INCR → const int
INCR_WRAP → const int
INT → const int
INT_2_10_10_10_REV → const int
INT_SAMPLER_2D → const int
INT_SAMPLER_2D_ARRAY → const int
INT_SAMPLER_3D → const int
INT_SAMPLER_CUBE → const int
INT_VEC2 → const int
INT_VEC3 → const int
INT_VEC4 → const int
INTERLEAVED_ATTRIBS → const int
INVALID_ENUM → const int
INVALID_FRAMEBUFFER_OPERATION → const int
INVALID_INDEX → const int
INVALID_OPERATION → const int
INVALID_VALUE → const int
INVERT → const int
KEEP → const int
LEQUAL → const int
LESS → const int
LINE_LOOP → const int
LINE_STRIP → const int
LINE_WIDTH → const int
LINEAR → const int
LINEAR_MIPMAP_LINEAR → const int
LINEAR_MIPMAP_NEAREST → const int
LINES → const int
LOW_FLOAT → const int
LOW_INT → const int
LUMINANCE → const int
LUMINANCE_ALPHA → const int
MAX → const int
MAX_3D_TEXTURE_SIZE → const int
MAX_ARRAY_TEXTURE_LAYERS → const int
MAX_CLIENT_WAIT_TIMEOUT_WEBGL → const int
MAX_COLOR_ATTACHMENTS → const int
MAX_COMBINED_FRAGMENT_UNIFORM_COMPONENTS → const int
MAX_COMBINED_TEXTURE_IMAGE_UNITS → const int
MAX_COMBINED_UNIFORM_BLOCKS → const int
MAX_COMBINED_VERTEX_UNIFORM_COMPONENTS → const int
MAX_CUBE_MAP_TEXTURE_SIZE → const int
MAX_DRAW_BUFFERS → const int
MAX_ELEMENT_INDEX → const int
MAX_ELEMENTS_INDICES → const int
MAX_ELEMENTS_VERTICES → const int
MAX_FRAGMENT_INPUT_COMPONENTS → const int
MAX_FRAGMENT_UNIFORM_BLOCKS → const int
MAX_FRAGMENT_UNIFORM_COMPONENTS → const int
MAX_FRAGMENT_UNIFORM_VECTORS → const int
MAX_PROGRAM_TEXEL_OFFSET → const int
MAX_RENDERBUFFER_SIZE → const int
MAX_SAMPLES → const int
MAX_SERVER_WAIT_TIMEOUT → const int
MAX_TEXTURE_IMAGE_UNITS → const int
MAX_TEXTURE_LOD_BIAS → const int
MAX_TEXTURE_SIZE → const int
MAX_TRANSFORM_FEEDBACK_INTERLEAVED_COMPONENTS → const int
MAX_TRANSFORM_FEEDBACK_SEPARATE_ATTRIBS → const int
MAX_TRANSFORM_FEEDBACK_SEPARATE_COMPONENTS → const int
MAX_UNIFORM_BLOCK_SIZE → const int
MAX_UNIFORM_BUFFER_BINDINGS → const int
MAX_VARYING_COMPONENTS → const int
MAX_VARYING_VECTORS → const int
MAX_VERTEX_ATTRIBS → const int
MAX_VERTEX_OUTPUT_COMPONENTS → const int
MAX_VERTEX_TEXTURE_IMAGE_UNITS → const int
MAX_VERTEX_UNIFORM_BLOCKS → const int
MAX_VERTEX_UNIFORM_COMPONENTS → const int
MAX_VERTEX_UNIFORM_VECTORS → const int
MAX_VIEWPORT_DIMS → const int
MEDIUM_FLOAT → const int
MEDIUM_INT → const int
MIN → const int
MIN_PROGRAM_TEXEL_OFFSET → const int
MIRRORED_REPEAT → const int
NEAREST → const int
NEAREST_MIPMAP_LINEAR → const int
NEAREST_MIPMAP_NEAREST → const int
NEVER → const int
NICEST → const int
NO_ERROR → const int
NONE → const int
NOTEQUAL → const int
OBJECT_TYPE → const int
ONE → const int
ONE_MINUS_CONSTANT_ALPHA → const int
ONE_MINUS_CONSTANT_COLOR → const int
ONE_MINUS_DST_ALPHA → const int
ONE_MINUS_DST_COLOR → const int
ONE_MINUS_SRC_ALPHA → const int
ONE_MINUS_SRC_COLOR → const int
OUT_OF_MEMORY → const int
PACK_ALIGNMENT → const int
PACK_ROW_LENGTH → const int
PACK_SKIP_PIXELS → const int
PACK_SKIP_ROWS → const int
PIXEL_PACK_BUFFER → const int
PIXEL_PACK_BUFFER_BINDING → const int
PIXEL_UNPACK_BUFFER → const int
PIXEL_UNPACK_BUFFER_BINDING → const int
POINTS → const int
POLYGON_OFFSET_FACTOR → const int
POLYGON_OFFSET_FILL → const int
POLYGON_OFFSET_UNITS → const int
QUERY_RESULT → const int
QUERY_RESULT_AVAILABLE → const int
R8 → const int
R8_SNORM → const int
R8I → const int
R8UI → const int
R11F_G11F_B10F → const int
R16F → const int
R16I → const int
R16UI → const int
R32F → const int
R32I → const int
R32UI → const int
RASTERIZER_DISCARD → const int
READ_BUFFER → const int
READ_FRAMEBUFFER → const int
READ_FRAMEBUFFER_BINDING → const int
RED → const int
RED_BITS → const int
RED_INTEGER → const int
RENDERBUFFER → const int
RENDERBUFFER_ALPHA_SIZE → const int
RENDERBUFFER_BINDING → const int
RENDERBUFFER_BLUE_SIZE → const int
RENDERBUFFER_DEPTH_SIZE → const int
RENDERBUFFER_GREEN_SIZE → const int
RENDERBUFFER_HEIGHT → const int
RENDERBUFFER_INTERNAL_FORMAT → const int
RENDERBUFFER_RED_SIZE → const int
RENDERBUFFER_SAMPLES → const int
RENDERBUFFER_STENCIL_SIZE → const int
RENDERBUFFER_WIDTH → const int
RENDERER → const int
REPEAT → const int
REPLACE → const int
RG → const int
RG8 → const int
RG8_SNORM → const int
RG8I → const int
RG8UI → const int
RG16F → const int
RG16I → const int
RG16UI → const int
RG32F → const int
RG32I → const int
RG32UI → const int
RG_INTEGER → const int
RGB → const int
RGB5_A1 → const int
RGB8 → const int
RGB8_SNORM → const int
RGB8I → const int
RGB8UI → const int
RGB9_E5 → const int
RGB10_A2 → const int
RGB10_A2UI → const int
RGB16F → const int
RGB16I → const int
RGB16UI → const int
RGB32F → const int
RGB32I → const int
RGB32UI → const int
RGB565 → const int
RGB_INTEGER → const int
RGBA → const int
RGBA4 → const int
RGBA8 → const int
RGBA8_SNORM → const int
RGBA8I → const int
RGBA8UI → const int
RGBA16F → const int
RGBA16I → const int
RGBA16UI → const int
RGBA32F → const int
RGBA32I → const int
RGBA32UI → const int
RGBA_INTEGER → const int
SAMPLE_ALPHA_TO_COVERAGE → const int
SAMPLE_BUFFERS → const int
SAMPLE_COVERAGE → const int
SAMPLE_COVERAGE_INVERT → const int
SAMPLE_COVERAGE_VALUE → const int
SAMPLER_2D → const int
SAMPLER_2D_ARRAY → const int
SAMPLER_2D_ARRAY_SHADOW → const int
SAMPLER_2D_SHADOW → const int
SAMPLER_3D → const int
SAMPLER_BINDING → const int
SAMPLER_CUBE → const int
SAMPLER_CUBE_SHADOW → const int
SAMPLES → const int
SCISSOR_BOX → const int
SCISSOR_TEST → const int
SEPARATE_ATTRIBS → const int
SHADER_TYPE → const int
SHADING_LANGUAGE_VERSION → const int
SHORT → const int
SIGNALED → const int
SIGNED_NORMALIZED → const int
SRC_ALPHA → const int
SRC_ALPHA_SATURATE → const int
SRC_COLOR → const int
SRGB → const int
SRGB8 → const int
SRGB8_ALPHA8 → const int
STATIC_COPY → const int
STATIC_DRAW → const int
STATIC_READ → const int
STENCIL → const int
STENCIL_ATTACHMENT → const int
STENCIL_BACK_FAIL → const int
STENCIL_BACK_FUNC → const int
STENCIL_BACK_PASS_DEPTH_FAIL → const int
STENCIL_BACK_PASS_DEPTH_PASS → const int
STENCIL_BACK_REF → const int
STENCIL_BACK_VALUE_MASK → const int
STENCIL_BACK_WRITEMASK → const int
STENCIL_BITS → const int
STENCIL_BUFFER_BIT → const int
STENCIL_CLEAR_VALUE → const int
STENCIL_FAIL → const int
STENCIL_FUNC → const int
STENCIL_INDEX8 → const int
STENCIL_PASS_DEPTH_FAIL → const int
STENCIL_PASS_DEPTH_PASS → const int
STENCIL_REF → const int
STENCIL_TEST → const int
STENCIL_VALUE_MASK → const int
STENCIL_WRITEMASK → const int
STREAM_COPY → const int
STREAM_DRAW → const int
STREAM_READ → const int
SUBPIXEL_BITS → const int
SYNC_CONDITION → const int
SYNC_FENCE → const int
SYNC_FLAGS → const int
SYNC_FLUSH_COMMANDS_BIT → const int
SYNC_GPU_COMMANDS_COMPLETE → const int
SYNC_STATUS → const int
TEXTURE → const int
TEXTURE0 → const int
TEXTURE1 → const int
TEXTURE2 → const int
TEXTURE3 → const int
TEXTURE4 → const int
TEXTURE5 → const int
TEXTURE6 → const int
TEXTURE7 → const int
TEXTURE8 → const int
TEXTURE9 → const int
TEXTURE10 → const int
TEXTURE11 → const int
TEXTURE12 → const int
TEXTURE13 → const int
TEXTURE14 → const int
TEXTURE15 → const int
TEXTURE16 → const int
TEXTURE17 → const int
TEXTURE18 → const int
TEXTURE19 → const int
TEXTURE20 → const int
TEXTURE21 → const int
TEXTURE22 → const int
TEXTURE23 → const int
TEXTURE24 → const int
TEXTURE25 → const int
TEXTURE26 → const int
TEXTURE27 → const int
TEXTURE28 → const int
TEXTURE29 → const int
TEXTURE30 → const int
TEXTURE31 → const int
TEXTURE_2D → const int
TEXTURE_2D_ARRAY → const int
TEXTURE_3D → const int
TEXTURE_BASE_LEVEL → const int
TEXTURE_BINDING_2D → const int
TEXTURE_BINDING_2D_ARRAY → const int
TEXTURE_BINDING_3D → const int
TEXTURE_BINDING_CUBE_MAP → const int
TEXTURE_COMPARE_FUNC → const int
TEXTURE_COMPARE_MODE → const int
TEXTURE_CUBE_MAP → const int
TEXTURE_CUBE_MAP_NEGATIVE_X → const int
TEXTURE_CUBE_MAP_NEGATIVE_Y → const int
TEXTURE_CUBE_MAP_NEGATIVE_Z → const int
TEXTURE_CUBE_MAP_POSITIVE_X → const int
TEXTURE_CUBE_MAP_POSITIVE_Y → const int
TEXTURE_CUBE_MAP_POSITIVE_Z → const int
TEXTURE_IMMUTABLE_FORMAT → const int
TEXTURE_IMMUTABLE_LEVELS → const int
TEXTURE_MAG_FILTER → const int
TEXTURE_MAX_LEVEL → const int
TEXTURE_MAX_LOD → const int
TEXTURE_MIN_FILTER → const int
TEXTURE_MIN_LOD → const int
TEXTURE_WRAP_R → const int
TEXTURE_WRAP_S → const int
TEXTURE_WRAP_T → const int
TIMEOUT_EXPIRED → const int
TIMEOUT_IGNORED → const int
TRANSFORM_FEEDBACK → const int
TRANSFORM_FEEDBACK_ACTIVE → const int
TRANSFORM_FEEDBACK_BINDING → const int
TRANSFORM_FEEDBACK_BUFFER → const int
TRANSFORM_FEEDBACK_BUFFER_BINDING → const int
TRANSFORM_FEEDBACK_BUFFER_MODE → const int
TRANSFORM_FEEDBACK_BUFFER_SIZE → const int
TRANSFORM_FEEDBACK_BUFFER_START → const int
TRANSFORM_FEEDBACK_PAUSED → const int
TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN → const int
TRANSFORM_FEEDBACK_VARYINGS → const int
TRIANGLE_FAN → const int
TRIANGLE_STRIP → const int
TRIANGLES → const int
UNIFORM_ARRAY_STRIDE → const int
UNIFORM_BLOCK_ACTIVE_UNIFORM_INDICES → const int
UNIFORM_BLOCK_ACTIVE_UNIFORMS → const int
UNIFORM_BLOCK_BINDING → const int
UNIFORM_BLOCK_DATA_SIZE → const int
UNIFORM_BLOCK_INDEX → const int
UNIFORM_BLOCK_REFERENCED_BY_FRAGMENT_SHADER → const int
UNIFORM_BLOCK_REFERENCED_BY_VERTEX_SHADER → const int
UNIFORM_BUFFER → const int
UNIFORM_BUFFER_BINDING → const int
UNIFORM_BUFFER_OFFSET_ALIGNMENT → const int
UNIFORM_BUFFER_SIZE → const int
UNIFORM_BUFFER_START → const int
UNIFORM_IS_ROW_MAJOR → const int
UNIFORM_MATRIX_STRIDE → const int
UNIFORM_OFFSET → const int
UNIFORM_SIZE → const int
UNIFORM_TYPE → const int
UNPACK_ALIGNMENT → const int
UNPACK_COLORSPACE_CONVERSION_WEBGL → const int
UNPACK_FLIP_Y_WEBGL → const int
UNPACK_IMAGE_HEIGHT → const int
UNPACK_PREMULTIPLY_ALPHA_WEBGL → const int
UNPACK_ROW_LENGTH → const int
UNPACK_SKIP_IMAGES → const int
UNPACK_SKIP_PIXELS → const int
UNPACK_SKIP_ROWS → const int
UNSIGNALED → const int
UNSIGNED_BYTE → const int
UNSIGNED_INT → const int
UNSIGNED_INT_2_10_10_10_REV → const int
UNSIGNED_INT_5_9_9_9_REV → const int
UNSIGNED_INT_10F_11F_11F_REV → const int
UNSIGNED_INT_24_8 → const int
UNSIGNED_INT_SAMPLER_2D → const int
UNSIGNED_INT_SAMPLER_2D_ARRAY → const int
UNSIGNED_INT_SAMPLER_3D → const int
UNSIGNED_INT_SAMPLER_CUBE → const int
UNSIGNED_INT_VEC2 → const int
UNSIGNED_INT_VEC3 → const int
UNSIGNED_INT_VEC4 → const int
UNSIGNED_NORMALIZED → const int
UNSIGNED_SHORT → const int
UNSIGNED_SHORT_4_4_4_4 → const int
UNSIGNED_SHORT_5_5_5_1 → const int
UNSIGNED_SHORT_5_6_5 → const int
VALIDATE_STATUS → const int
VENDOR → const int
VERSION → const int
VERTEX_ARRAY_BINDING → const int
VERTEX_ATTRIB_ARRAY_BUFFER_BINDING → const int
VERTEX_ATTRIB_ARRAY_DIVISOR → const int
VERTEX_ATTRIB_ARRAY_ENABLED → const int
VERTEX_ATTRIB_ARRAY_INTEGER → const int
VERTEX_ATTRIB_ARRAY_NORMALIZED → const int
VERTEX_ATTRIB_ARRAY_POINTER → const int
VERTEX_ATTRIB_ARRAY_SIZE → const int
VERTEX_ATTRIB_ARRAY_STRIDE → const int
VERTEX_ATTRIB_ARRAY_TYPE → const int
VERTEX_SHADER → const int
VIEWPORT → const int
WAIT_FAILED → const int
ZERO → const int